@@ -197,14 +197,14 @@ class Visualisation:
 
     def to_pdf(self, filename="out.pdf", **kwargs):
         """Outputs the generated PDF to a file."""
-        pdf = self.get_pdf()
+        pdf = self.get_pdf(kwargs)
         file = open(filename, "wb")
         file.write(pdf)
         file.close()
 
     def to_mp4(self, filename="out.mp4", **kwargs):
         """Outputs the generated MP4 to a file."""
-        pdf = self.get_mp4()
+        pdf = self.get_mp4(kwargs)
         file = open(filename, "wb")
         file.write(pdf)
         file.close()
@@ -230,7 +230,7 @@ class Visualisation:
         from IPython.core.display import Video
         from IPython.display import display
 
-        video = self.get_mp4()
+        video = self.get_mp4(kwargs)
         display(
             Video(
                 video,
